#
# spec file for package perl-AppConfig
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name AppConfig
Name:           perl-AppConfig
Version:        1.710.0
Release:        1.1
# 1.71 -> normalize -> 1.710.0
%define cpan_version 1.71
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        AppConfig is a bundle of Perl5 modules for reading configuration files a[cut]
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/N/NE/NEILB/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Pod) >= 1.0.0
Provides:       perl(AppConfig) = %{version}
Provides:       perl(AppConfig::Args) = %{version}
Provides:       perl(AppConfig::CGI) = %{version}
Provides:       perl(AppConfig::File) = %{version}
Provides:       perl(AppConfig::Getopt) = %{version}
Provides:       perl(AppConfig::State) = %{version}
Provides:       perl(AppConfig::Sys) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
AppConfig is a Perl5 module for managing application configuration
information. It maintains the state of any number of variables and provides
methods for parsing configuration files, command line arguments and CGI
script parameters.

Variables values may be set via configuration files. Variables may be flags
(On/Off), take a single value, or take multiple values stored as a list or
hash. The number of arguments a variable expects is determined by its
configuration when defined.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README TODO
%license LICENSE

%changelog
* Thu Jun 12 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
- Add cpanspec.yml for automatic spec generation
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.71
  see /usr/share/doc/packages/perl-AppConfig/Changes
* Wed Dec  7 2011 coolo@suse.com
- use spdx license
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Jul  9 2007 anicka@suse.cz
- update to 1.66
  * Removed File::HomeDir from the test scripts.
* Mon Jun 11 2007 anicka@suse.cz
- update to 1.65
  * documentation added
- move testing to %%check
* Wed May 16 2007 pth@suse.de
- Add explicit dependencies on perl-File-HomeDir.
- Run tests.
* Tue Jan  9 2007 anicka@suse.cz
- update to 1.64
  * Bug fix to prevent crashing for users with no home directory
  * Increase File::HomeDir dep to 0.61 which supports no home
  directory cases properly.
* Wed Sep 13 2006 anicka@suse.cz
- update to 1.63
  * removed "use warnings" and "use base Exporter"
  * Use File::HomeDir to find $HOME
  * Fixed a POD bug in AppConfig::Sys and added a 99_pod.t test
  * Added a LICENSE file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 31 2005 dmueller@suse.de
- build as nonroot
* Thu Feb 26 2004 mjancar@suse.cz
- update to 1.56
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 freitag@suse.de
- fixed specfile to use vendorbranch and use macros
* Sun Jun 22 2003 coolo@suse.de
- package directories
* Mon May 19 2003 freitag@suse.de
- removed perllocal.pod and updated to new version 1.55
* Thu Jan 30 2003 ro@suse.de
- no noarch
* Thu Nov 28 2002 freitag@suse.de
- added noarch Architecture flag.
* Thu Nov 28 2002 freitag@suse.de
- new package perl-AppConfig
